@@ -13,7 +13,7 @@ import json
 import pandas as pd
 import pickle
 from datetime import datetime as dt
-from pandas_datareader import data
+#from pandas_datareader import data
 
 from napoleontoolbox.connector import shifting_utility
 from npxlogger import log
@@ -62,13 +62,15 @@ def fetch_equity_daily_data(ticker=None, provider = 'yahoo', starting_date=None,
         'SPX' : '^GSPC',
         'SX5E' : '^STOXX50E',
     }
+
+    yahoo_ticker = ticker
     try:
         yahoo_ticker = yahoo_tickers_equivalents[ticker]
     except:
         log.info('No yahoo ticker equivalent for this ticker. Check dictionary of yahoo tickers equivalents')
 
     if provider == 'yahoo':
-        data_df = data.DataReader(yahoo_ticker, provider, starting_date, running_date)
+        data_df = None# data.DataReader(yahoo_ticker, provider, starting_date, running_date)
         data_df.columns = map(str.lower, data_df.columns)
         filename = ticker+'_'+starting_date.strftime('%d_%b_%Y')+'_'+running_date.strftime('%d_%b_%Y')+'_daily_returns.pkl'
         data_df.to_pickle(local_root_directory+filename)
